import os
import sys

import names
import squishtest


class SquishLibrary:
    """Example Squish Library for use with the Robot Framework"""

    ROBOT_LIBRARY_SCOPE = 'TEST CASE'

    def __init__(self):
        pass

    def start_application(self, aut, wrapper):
        """Starts AUT, args=(aut, wrapper)"""
        print("*INFO* Starting AUT: %s with %s wrapper" % (aut, wrapper))

        # Remove double quotes for setWrappersForApplication
        aut = aut.replace('"', '')

        squishtest.testSettings.setWrappersForApplication(aut, wrapper)

        # Add double quotes for startApplication:
        squishtest.startApplication('"' + aut + '"')

    def __LookupRealName__(self, name):
        split = name.split('.')
        module = sys.modules.get(split[0])
        return module.__getattribute__(split[1])

    def click_button(self, objName):
        """Clicks on button, args=(objName)"""
        squishtest.clickButton(squishtest.waitForObject(self.__LookupRealName__(objName)))

    def enter(self, objName, txt):
         """Enters given text into TextField, args=(objName, txt)"""
         print('*INFO* Entering "%s" into object "%s"' %(txt, objName))
         squishtest.type(squishtest.waitForObject(self.__LookupRealName__(objName)), txt)

    def property_should_be(self, objName, prop, expected):
        """Verifies that given object has property with expected value, args= (objName, prop, expected)"""
        print("*INFO* Got arguments: %s, %s, %s" % (objName, prop, expected))
        obj = squishtest.waitForObject(self.__LookupRealName__(objName))
        val = getattr(obj, prop)
        if not (str(val) == expected):
                raise AssertionError("Expected value is %s, but got: %s" % (expected, val))
        print("*INFO* Assertion passed, value is %s" % val)


# Execute this on module level, because it must
# be executed only once:
squishtest.setTestResult("xml3.4", "%s/squishtest_results_xml" % os.environ["RESULTS_DIR"])
